@@ -1,18 +1,54 @@
-#[doc = "Reader of register UARTCR"]
-pub type R = crate::R<u32, super::UARTCR>;
-#[doc = "Writer for register UARTCR"]
-pub type W = crate::W<u32, super::UARTCR>;
-#[doc = "Register UARTCR `reset()`'s with value 0x0300"]
-impl crate::ResetValue for super::UARTCR {
-    type Type = u32;
+#[doc = "Register `UARTCR` reader"]
+pub struct R(crate::R<UARTCR_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<UARTCR_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0x0300
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
-#[doc = "Reader of field `CTSEN`"]
-pub type CTSEN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `CTSEN`"]
+impl From<crate::R<UARTCR_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<UARTCR_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `UARTCR` writer"]
+pub struct W(crate::W<UARTCR_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<UARTCR_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<UARTCR_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<UARTCR_SPEC>) -> Self {
+        W(writer)
+    }
+}
+#[doc = "Field `CTSEN` reader - CTS hardware flow control enable. If this bit is set to 1, CTS hardware flow control is enabled. Data is only transmitted when the nUARTCTS signal is asserted."]
+pub struct CTSEN_R(crate::FieldReader<bool, bool>);
+impl CTSEN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        CTSEN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for CTSEN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CTSEN` writer - CTS hardware flow control enable. If this bit is set to 1, CTS hardware flow control is enabled. Data is only transmitted when the nUARTCTS signal is asserted."]
 pub struct CTSEN_W<'a> {
     w: &'a mut W,
 }
@@ -30,13 +66,25 @@ impl<'a> CTSEN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
-#[doc = "Reader of field `RTSEN`"]
-pub type RTSEN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `RTSEN`"]
+#[doc = "Field `RTSEN` reader - RTS hardware flow control enable. If this bit is set to 1, RTS hardware flow control is enabled. Data is only requested when there is space in the receive FIFO for it to be received."]
+pub struct RTSEN_R(crate::FieldReader<bool, bool>);
+impl RTSEN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        RTSEN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for RTSEN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `RTSEN` writer - RTS hardware flow control enable. If this bit is set to 1, RTS hardware flow control is enabled. Data is only requested when there is space in the receive FIFO for it to be received."]
 pub struct RTSEN_W<'a> {
     w: &'a mut W,
 }
@@ -54,13 +102,25 @@ impl<'a> RTSEN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
-#[doc = "Reader of field `OUT2`"]
-pub type OUT2_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OUT2`"]
+#[doc = "Field `OUT2` reader - This bit is the complement of the UART Out2 (nUARTOut2) modem status output. That is, when the bit is programmed to a 1, the output is 0. For DTE this can be used as Ring Indicator (RI)."]
+pub struct OUT2_R(crate::FieldReader<bool, bool>);
+impl OUT2_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        OUT2_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OUT2_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OUT2` writer - This bit is the complement of the UART Out2 (nUARTOut2) modem status output. That is, when the bit is programmed to a 1, the output is 0. For DTE this can be used as Ring Indicator (RI)."]
 pub struct OUT2_W<'a> {
     w: &'a mut W,
 }
@@ -78,13 +138,25 @@ impl<'a> OUT2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
-#[doc = "Reader of field `OUT1`"]
-pub type OUT1_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OUT1`"]
+#[doc = "Field `OUT1` reader - This bit is the complement of the UART Out1 (nUARTOut1) modem status output. That is, when the bit is programmed to a 1 the output is 0. For DTE this can be used as Data Carrier Detect (DCD)."]
+pub struct OUT1_R(crate::FieldReader<bool, bool>);
+impl OUT1_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        OUT1_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OUT1_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OUT1` writer - This bit is the complement of the UART Out1 (nUARTOut1) modem status output. That is, when the bit is programmed to a 1 the output is 0. For DTE this can be used as Data Carrier Detect (DCD)."]
 pub struct OUT1_W<'a> {
     w: &'a mut W,
 }
@@ -102,13 +174,25 @@ impl<'a> OUT1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
-#[doc = "Reader of field `RTS`"]
-pub type RTS_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `RTS`"]
+#[doc = "Field `RTS` reader - Request to send. This bit is the complement of the UART request to send, nUARTRTS, modem status output. That is, when the bit is programmed to a 1 then nUARTRTS is LOW."]
+pub struct RTS_R(crate::FieldReader<bool, bool>);
+impl RTS_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        RTS_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for RTS_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `RTS` writer - Request to send. This bit is the complement of the UART request to send, nUARTRTS, modem status output. That is, when the bit is programmed to a 1 then nUARTRTS is LOW."]
 pub struct RTS_W<'a> {
     w: &'a mut W,
 }
@@ -126,13 +210,25 @@ impl<'a> RTS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
-#[doc = "Reader of field `DTR`"]
-pub type DTR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `DTR`"]
+#[doc = "Field `DTR` reader - Data transmit ready. This bit is the complement of the UART data transmit ready, nUARTDTR, modem status output. That is, when the bit is programmed to a 1 then nUARTDTR is LOW."]
+pub struct DTR_R(crate::FieldReader<bool, bool>);
+impl DTR_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DTR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for DTR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `DTR` writer - Data transmit ready. This bit is the complement of the UART data transmit ready, nUARTDTR, modem status output. That is, when the bit is programmed to a 1 then nUARTDTR is LOW."]
 pub struct DTR_W<'a> {
     w: &'a mut W,
 }
@@ -150,13 +246,25 @@ impl<'a> DTR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
-#[doc = "Reader of field `RXE`"]
-pub type RXE_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `RXE`"]
+#[doc = "Field `RXE` reader - Receive enable. If this bit is set to 1, the receive section of the UART is enabled. Data reception occurs for either UART signals or SIR signals depending on the setting of the SIREN bit. When the UART is disabled in the middle of reception, it completes the current character before stopping."]
+pub struct RXE_R(crate::FieldReader<bool, bool>);
+impl RXE_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        RXE_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for RXE_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `RXE` writer - Receive enable. If this bit is set to 1, the receive section of the UART is enabled. Data reception occurs for either UART signals or SIR signals depending on the setting of the SIREN bit. When the UART is disabled in the middle of reception, it completes the current character before stopping."]
 pub struct RXE_W<'a> {
     w: &'a mut W,
 }
@@ -174,13 +282,25 @@ impl<'a> RXE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
-#[doc = "Reader of field `TXE`"]
-pub type TXE_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TXE`"]
+#[doc = "Field `TXE` reader - Transmit enable. If this bit is set to 1, the transmit section of the UART is enabled. Data transmission occurs for either UART signals, or SIR signals depending on the setting of the SIREN bit. When the UART is disabled in the middle of transmission, it completes the current character before stopping."]
+pub struct TXE_R(crate::FieldReader<bool, bool>);
+impl TXE_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        TXE_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TXE_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TXE` writer - Transmit enable. If this bit is set to 1, the transmit section of the UART is enabled. Data transmission occurs for either UART signals, or SIR signals depending on the setting of the SIREN bit. When the UART is disabled in the middle of transmission, it completes the current character before stopping."]
 pub struct TXE_W<'a> {
     w: &'a mut W,
 }
@@ -198,13 +318,25 @@ impl<'a> TXE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
-#[doc = "Reader of field `LBE`"]
-pub type LBE_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `LBE`"]
+#[doc = "Field `LBE` reader - Loopback enable. If this bit is set to 1 and the SIREN bit is set to 1 and the SIRTEST bit in the Test Control Register, UARTTCR is set to 1, then the nSIROUT path is inverted, and fed through to the SIRIN path. The SIRTEST bit in the test register must be set to 1 to override the normal half-duplex SIR operation. This must be the requirement for accessing the test registers during normal operation, and SIRTEST must be cleared to 0 when loopback testing is finished. This feature reduces the amount of external coupling required during system test. If this bit is set to 1, and the SIRTEST bit is set to 0, the UARTTXD path is fed through to the UARTRXD path. In either SIR mode or UART mode, when this bit is set, the modem outputs are also fed through to the modem inputs. This bit is cleared to 0 on reset, to disable loopback."]
+pub struct LBE_R(crate::FieldReader<bool, bool>);
+impl LBE_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        LBE_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for LBE_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LBE` writer - Loopback enable. If this bit is set to 1 and the SIREN bit is set to 1 and the SIRTEST bit in the Test Control Register, UARTTCR is set to 1, then the nSIROUT path is inverted, and fed through to the SIRIN path. The SIRTEST bit in the test register must be set to 1 to override the normal half-duplex SIR operation. This must be the requirement for accessing the test registers during normal operation, and SIRTEST must be cleared to 0 when loopback testing is finished. This feature reduces the amount of external coupling required during system test. If this bit is set to 1, and the SIRTEST bit is set to 0, the UARTTXD path is fed through to the UARTRXD path. In either SIR mode or UART mode, when this bit is set, the modem outputs are also fed through to the modem inputs. This bit is cleared to 0 on reset, to disable loopback."]
 pub struct LBE_W<'a> {
     w: &'a mut W,
 }
@@ -222,13 +354,25 @@ impl<'a> LBE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
-#[doc = "Reader of field `SIRLP`"]
-pub type SIRLP_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `SIRLP`"]
+#[doc = "Field `SIRLP` reader - SIR low-power IrDA mode. This bit selects the IrDA encoding mode. If this bit is cleared to 0, low-level bits are transmitted as an active high pulse with a width of 3 / 16th of the bit period. If this bit is set to 1, low-level bits are transmitted with a pulse width that is 3 times the period of the IrLPBaud16 input signal, regardless of the selected bit rate. Setting this bit uses less power, but might reduce transmission distances."]
+pub struct SIRLP_R(crate::FieldReader<bool, bool>);
+impl SIRLP_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        SIRLP_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for SIRLP_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `SIRLP` writer - SIR low-power IrDA mode. This bit selects the IrDA encoding mode. If this bit is cleared to 0, low-level bits are transmitted as an active high pulse with a width of 3 / 16th of the bit period. If this bit is set to 1, low-level bits are transmitted with a pulse width that is 3 times the period of the IrLPBaud16 input signal, regardless of the selected bit rate. Setting this bit uses less power, but might reduce transmission distances."]
 pub struct SIRLP_W<'a> {
     w: &'a mut W,
 }
@@ -246,13 +390,25 @@ impl<'a> SIRLP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
-#[doc = "Reader of field `SIREN`"]
-pub type SIREN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `SIREN`"]
+#[doc = "Field `SIREN` reader - SIR enable: 0 = IrDA SIR ENDEC is disabled. nSIROUT remains LOW (no light pulse generated), and signal transitions on SIRIN have no effect. 1 = IrDA SIR ENDEC is enabled. Data is transmitted and received on nSIROUT and SIRIN. UARTTXD remains HIGH, in the marking state. Signal transitions on UARTRXD or modem status inputs have no effect. This bit has no effect if the UARTEN bit disables the UART."]
+pub struct SIREN_R(crate::FieldReader<bool, bool>);
+impl SIREN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        SIREN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for SIREN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `SIREN` writer - SIR enable: 0 = IrDA SIR ENDEC is disabled. nSIROUT remains LOW (no light pulse generated), and signal transitions on SIRIN have no effect. 1 = IrDA SIR ENDEC is enabled. Data is transmitted and received on nSIROUT and SIRIN. UARTTXD remains HIGH, in the marking state. Signal transitions on UARTRXD or modem status inputs have no effect. This bit has no effect if the UARTEN bit disables the UART."]
 pub struct SIREN_W<'a> {
     w: &'a mut W,
 }
@@ -270,13 +426,25 @@ impl<'a> SIREN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
-#[doc = "Reader of field `UARTEN`"]
-pub type UARTEN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `UARTEN`"]
+#[doc = "Field `UARTEN` reader - UART enable: 0 = UART is disabled. If the UART is disabled in the middle of transmission or reception, it completes the current character before stopping. 1 = the UART is enabled. Data transmission and reception occurs for either UART signals or SIR signals depending on the setting of the SIREN bit."]
+pub struct UARTEN_R(crate::FieldReader<bool, bool>);
+impl UARTEN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        UARTEN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for UARTEN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `UARTEN` writer - UART enable: 0 = UART is disabled. If the UART is disabled in the middle of transmission or reception, it completes the current character before stopping. 1 = the UART is enabled. Data transmission and reception occurs for either UART signals or SIR signals depending on the setting of the SIREN bit."]
 pub struct UARTEN_W<'a> {
     w: &'a mut W,
 }
@@ -294,7 +462,7 @@ impl<'a> UARTEN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -421,4 +589,34 @@ impl W {
     pub fn uarten(&mut self) -> UARTEN_W {
         UARTEN_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Control Register, UARTCR  
+
+This register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).  
+
+For information about available fields see [uartcr](index.html) module"]
+pub struct UARTCR_SPEC;
+impl crate::RegisterSpec for UARTCR_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [uartcr::R](R) reader structure"]
+impl crate::Readable for UARTCR_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [uartcr::W](W) writer structure"]
+impl crate::Writable for UARTCR_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets UARTCR to value 0x0300"]
+impl crate::Resettable for UARTCR_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0x0300
+    }
 }
