@@ -1,18 +1,54 @@
-#[doc = "Reader of register EP_STATUS_STALL_NAK"]
-pub type R = crate::R<u32, super::EP_STATUS_STALL_NAK>;
-#[doc = "Writer for register EP_STATUS_STALL_NAK"]
-pub type W = crate::W<u32, super::EP_STATUS_STALL_NAK>;
-#[doc = "Register EP_STATUS_STALL_NAK `reset()`'s with value 0"]
-impl crate::ResetValue for super::EP_STATUS_STALL_NAK {
-    type Type = u32;
+#[doc = "Register `EP_STATUS_STALL_NAK` reader"]
+pub struct R(crate::R<EP_STATUS_STALL_NAK_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<EP_STATUS_STALL_NAK_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
-#[doc = "Reader of field `EP15_OUT`"]
-pub type EP15_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP15_OUT`"]
+impl From<crate::R<EP_STATUS_STALL_NAK_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<EP_STATUS_STALL_NAK_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `EP_STATUS_STALL_NAK` writer"]
+pub struct W(crate::W<EP_STATUS_STALL_NAK_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<EP_STATUS_STALL_NAK_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<EP_STATUS_STALL_NAK_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<EP_STATUS_STALL_NAK_SPEC>) -> Self {
+        W(writer)
+    }
+}
+#[doc = "Field `EP15_OUT` reader - "]
+pub struct EP15_OUT_R(crate::FieldReader<bool, bool>);
+impl EP15_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP15_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP15_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP15_OUT` writer - "]
 pub struct EP15_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -30,13 +66,25 @@ impl<'a> EP15_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | (((value as u32) & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
         self.w
     }
 }
-#[doc = "Reader of field `EP15_IN`"]
-pub type EP15_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP15_IN`"]
+#[doc = "Field `EP15_IN` reader - "]
+pub struct EP15_IN_R(crate::FieldReader<bool, bool>);
+impl EP15_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP15_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP15_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP15_IN` writer - "]
 pub struct EP15_IN_W<'a> {
     w: &'a mut W,
 }
@@ -54,13 +102,25 @@ impl<'a> EP15_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | (((value as u32) & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
         self.w
     }
 }
-#[doc = "Reader of field `EP14_OUT`"]
-pub type EP14_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP14_OUT`"]
+#[doc = "Field `EP14_OUT` reader - "]
+pub struct EP14_OUT_R(crate::FieldReader<bool, bool>);
+impl EP14_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP14_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP14_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP14_OUT` writer - "]
 pub struct EP14_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -78,13 +138,25 @@ impl<'a> EP14_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | (((value as u32) & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
         self.w
     }
 }
-#[doc = "Reader of field `EP14_IN`"]
-pub type EP14_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP14_IN`"]
+#[doc = "Field `EP14_IN` reader - "]
+pub struct EP14_IN_R(crate::FieldReader<bool, bool>);
+impl EP14_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP14_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP14_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP14_IN` writer - "]
 pub struct EP14_IN_W<'a> {
     w: &'a mut W,
 }
@@ -102,13 +174,25 @@ impl<'a> EP14_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | (((value as u32) & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
         self.w
     }
 }
-#[doc = "Reader of field `EP13_OUT`"]
-pub type EP13_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP13_OUT`"]
+#[doc = "Field `EP13_OUT` reader - "]
+pub struct EP13_OUT_R(crate::FieldReader<bool, bool>);
+impl EP13_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP13_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP13_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP13_OUT` writer - "]
 pub struct EP13_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -126,13 +210,25 @@ impl<'a> EP13_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | (((value as u32) & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
         self.w
     }
 }
-#[doc = "Reader of field `EP13_IN`"]
-pub type EP13_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP13_IN`"]
+#[doc = "Field `EP13_IN` reader - "]
+pub struct EP13_IN_R(crate::FieldReader<bool, bool>);
+impl EP13_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP13_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP13_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP13_IN` writer - "]
 pub struct EP13_IN_W<'a> {
     w: &'a mut W,
 }
@@ -150,13 +246,25 @@ impl<'a> EP13_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | (((value as u32) & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
         self.w
     }
 }
-#[doc = "Reader of field `EP12_OUT`"]
-pub type EP12_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP12_OUT`"]
+#[doc = "Field `EP12_OUT` reader - "]
+pub struct EP12_OUT_R(crate::FieldReader<bool, bool>);
+impl EP12_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP12_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP12_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP12_OUT` writer - "]
 pub struct EP12_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -174,13 +282,25 @@ impl<'a> EP12_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | (((value as u32) & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
         self.w
     }
 }
-#[doc = "Reader of field `EP12_IN`"]
-pub type EP12_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP12_IN`"]
+#[doc = "Field `EP12_IN` reader - "]
+pub struct EP12_IN_R(crate::FieldReader<bool, bool>);
+impl EP12_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP12_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP12_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP12_IN` writer - "]
 pub struct EP12_IN_W<'a> {
     w: &'a mut W,
 }
@@ -198,13 +318,25 @@ impl<'a> EP12_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | (((value as u32) & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
         self.w
     }
 }
-#[doc = "Reader of field `EP11_OUT`"]
-pub type EP11_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP11_OUT`"]
+#[doc = "Field `EP11_OUT` reader - "]
+pub struct EP11_OUT_R(crate::FieldReader<bool, bool>);
+impl EP11_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP11_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP11_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP11_OUT` writer - "]
 pub struct EP11_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -222,13 +354,25 @@ impl<'a> EP11_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | (((value as u32) & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
         self.w
     }
 }
-#[doc = "Reader of field `EP11_IN`"]
-pub type EP11_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP11_IN`"]
+#[doc = "Field `EP11_IN` reader - "]
+pub struct EP11_IN_R(crate::FieldReader<bool, bool>);
+impl EP11_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP11_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP11_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP11_IN` writer - "]
 pub struct EP11_IN_W<'a> {
     w: &'a mut W,
 }
@@ -246,13 +390,25 @@ impl<'a> EP11_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | (((value as u32) & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
         self.w
     }
 }
-#[doc = "Reader of field `EP10_OUT`"]
-pub type EP10_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP10_OUT`"]
+#[doc = "Field `EP10_OUT` reader - "]
+pub struct EP10_OUT_R(crate::FieldReader<bool, bool>);
+impl EP10_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP10_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP10_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP10_OUT` writer - "]
 pub struct EP10_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -270,13 +426,25 @@ impl<'a> EP10_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | (((value as u32) & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
         self.w
     }
 }
-#[doc = "Reader of field `EP10_IN`"]
-pub type EP10_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP10_IN`"]
+#[doc = "Field `EP10_IN` reader - "]
+pub struct EP10_IN_R(crate::FieldReader<bool, bool>);
+impl EP10_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP10_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP10_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP10_IN` writer - "]
 pub struct EP10_IN_W<'a> {
     w: &'a mut W,
 }
@@ -294,13 +462,25 @@ impl<'a> EP10_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
-#[doc = "Reader of field `EP9_OUT`"]
-pub type EP9_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP9_OUT`"]
+#[doc = "Field `EP9_OUT` reader - "]
+pub struct EP9_OUT_R(crate::FieldReader<bool, bool>);
+impl EP9_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP9_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP9_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP9_OUT` writer - "]
 pub struct EP9_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -318,13 +498,25 @@ impl<'a> EP9_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
-#[doc = "Reader of field `EP9_IN`"]
-pub type EP9_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP9_IN`"]
+#[doc = "Field `EP9_IN` reader - "]
+pub struct EP9_IN_R(crate::FieldReader<bool, bool>);
+impl EP9_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP9_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP9_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP9_IN` writer - "]
 pub struct EP9_IN_W<'a> {
     w: &'a mut W,
 }
@@ -342,13 +534,25 @@ impl<'a> EP9_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
-#[doc = "Reader of field `EP8_OUT`"]
-pub type EP8_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP8_OUT`"]
+#[doc = "Field `EP8_OUT` reader - "]
+pub struct EP8_OUT_R(crate::FieldReader<bool, bool>);
+impl EP8_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP8_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP8_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP8_OUT` writer - "]
 pub struct EP8_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -366,13 +570,25 @@ impl<'a> EP8_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
-#[doc = "Reader of field `EP8_IN`"]
-pub type EP8_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP8_IN`"]
+#[doc = "Field `EP8_IN` reader - "]
+pub struct EP8_IN_R(crate::FieldReader<bool, bool>);
+impl EP8_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP8_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP8_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP8_IN` writer - "]
 pub struct EP8_IN_W<'a> {
     w: &'a mut W,
 }
@@ -390,13 +606,25 @@ impl<'a> EP8_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
-#[doc = "Reader of field `EP7_OUT`"]
-pub type EP7_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP7_OUT`"]
+#[doc = "Field `EP7_OUT` reader - "]
+pub struct EP7_OUT_R(crate::FieldReader<bool, bool>);
+impl EP7_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP7_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP7_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP7_OUT` writer - "]
 pub struct EP7_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -414,13 +642,25 @@ impl<'a> EP7_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
-#[doc = "Reader of field `EP7_IN`"]
-pub type EP7_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP7_IN`"]
+#[doc = "Field `EP7_IN` reader - "]
+pub struct EP7_IN_R(crate::FieldReader<bool, bool>);
+impl EP7_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP7_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP7_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP7_IN` writer - "]
 pub struct EP7_IN_W<'a> {
     w: &'a mut W,
 }
@@ -438,13 +678,25 @@ impl<'a> EP7_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
-#[doc = "Reader of field `EP6_OUT`"]
-pub type EP6_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP6_OUT`"]
+#[doc = "Field `EP6_OUT` reader - "]
+pub struct EP6_OUT_R(crate::FieldReader<bool, bool>);
+impl EP6_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP6_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP6_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP6_OUT` writer - "]
 pub struct EP6_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -462,13 +714,25 @@ impl<'a> EP6_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
-#[doc = "Reader of field `EP6_IN`"]
-pub type EP6_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP6_IN`"]
+#[doc = "Field `EP6_IN` reader - "]
+pub struct EP6_IN_R(crate::FieldReader<bool, bool>);
+impl EP6_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP6_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP6_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP6_IN` writer - "]
 pub struct EP6_IN_W<'a> {
     w: &'a mut W,
 }
@@ -486,13 +750,25 @@ impl<'a> EP6_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
-#[doc = "Reader of field `EP5_OUT`"]
-pub type EP5_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP5_OUT`"]
+#[doc = "Field `EP5_OUT` reader - "]
+pub struct EP5_OUT_R(crate::FieldReader<bool, bool>);
+impl EP5_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP5_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP5_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP5_OUT` writer - "]
 pub struct EP5_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -510,13 +786,25 @@ impl<'a> EP5_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
-#[doc = "Reader of field `EP5_IN`"]
-pub type EP5_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP5_IN`"]
+#[doc = "Field `EP5_IN` reader - "]
+pub struct EP5_IN_R(crate::FieldReader<bool, bool>);
+impl EP5_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP5_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP5_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP5_IN` writer - "]
 pub struct EP5_IN_W<'a> {
     w: &'a mut W,
 }
@@ -534,13 +822,25 @@ impl<'a> EP5_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
-#[doc = "Reader of field `EP4_OUT`"]
-pub type EP4_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP4_OUT`"]
+#[doc = "Field `EP4_OUT` reader - "]
+pub struct EP4_OUT_R(crate::FieldReader<bool, bool>);
+impl EP4_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP4_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP4_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP4_OUT` writer - "]
 pub struct EP4_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -558,13 +858,25 @@ impl<'a> EP4_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
-#[doc = "Reader of field `EP4_IN`"]
-pub type EP4_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP4_IN`"]
+#[doc = "Field `EP4_IN` reader - "]
+pub struct EP4_IN_R(crate::FieldReader<bool, bool>);
+impl EP4_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP4_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP4_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP4_IN` writer - "]
 pub struct EP4_IN_W<'a> {
     w: &'a mut W,
 }
@@ -582,13 +894,25 @@ impl<'a> EP4_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
-#[doc = "Reader of field `EP3_OUT`"]
-pub type EP3_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP3_OUT`"]
+#[doc = "Field `EP3_OUT` reader - "]
+pub struct EP3_OUT_R(crate::FieldReader<bool, bool>);
+impl EP3_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP3_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP3_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP3_OUT` writer - "]
 pub struct EP3_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -606,13 +930,25 @@ impl<'a> EP3_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
-#[doc = "Reader of field `EP3_IN`"]
-pub type EP3_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP3_IN`"]
+#[doc = "Field `EP3_IN` reader - "]
+pub struct EP3_IN_R(crate::FieldReader<bool, bool>);
+impl EP3_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP3_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP3_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP3_IN` writer - "]
 pub struct EP3_IN_W<'a> {
     w: &'a mut W,
 }
@@ -630,13 +966,25 @@ impl<'a> EP3_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
-#[doc = "Reader of field `EP2_OUT`"]
-pub type EP2_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP2_OUT`"]
+#[doc = "Field `EP2_OUT` reader - "]
+pub struct EP2_OUT_R(crate::FieldReader<bool, bool>);
+impl EP2_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP2_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP2_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP2_OUT` writer - "]
 pub struct EP2_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -654,13 +1002,25 @@ impl<'a> EP2_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
-#[doc = "Reader of field `EP2_IN`"]
-pub type EP2_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP2_IN`"]
+#[doc = "Field `EP2_IN` reader - "]
+pub struct EP2_IN_R(crate::FieldReader<bool, bool>);
+impl EP2_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP2_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP2_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP2_IN` writer - "]
 pub struct EP2_IN_W<'a> {
     w: &'a mut W,
 }
@@ -678,13 +1038,25 @@ impl<'a> EP2_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
-#[doc = "Reader of field `EP1_OUT`"]
-pub type EP1_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP1_OUT`"]
+#[doc = "Field `EP1_OUT` reader - "]
+pub struct EP1_OUT_R(crate::FieldReader<bool, bool>);
+impl EP1_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP1_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP1_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP1_OUT` writer - "]
 pub struct EP1_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -702,13 +1074,25 @@ impl<'a> EP1_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
-#[doc = "Reader of field `EP1_IN`"]
-pub type EP1_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP1_IN`"]
+#[doc = "Field `EP1_IN` reader - "]
+pub struct EP1_IN_R(crate::FieldReader<bool, bool>);
+impl EP1_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP1_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP1_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP1_IN` writer - "]
 pub struct EP1_IN_W<'a> {
     w: &'a mut W,
 }
@@ -726,13 +1110,25 @@ impl<'a> EP1_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
-#[doc = "Reader of field `EP0_OUT`"]
-pub type EP0_OUT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP0_OUT`"]
+#[doc = "Field `EP0_OUT` reader - "]
+pub struct EP0_OUT_R(crate::FieldReader<bool, bool>);
+impl EP0_OUT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP0_OUT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP0_OUT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP0_OUT` writer - "]
 pub struct EP0_OUT_W<'a> {
     w: &'a mut W,
 }
@@ -750,13 +1146,25 @@ impl<'a> EP0_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
-#[doc = "Reader of field `EP0_IN`"]
-pub type EP0_IN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EP0_IN`"]
+#[doc = "Field `EP0_IN` reader - "]
+pub struct EP0_IN_R(crate::FieldReader<bool, bool>);
+impl EP0_IN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EP0_IN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EP0_IN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EP0_IN` writer - "]
 pub struct EP0_IN_W<'a> {
     w: &'a mut W,
 }
@@ -774,7 +1182,7 @@ impl<'a> EP0_IN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -1101,4 +1509,34 @@ impl W {
     pub fn ep0_in(&mut self) -> EP0_IN_W {
         EP0_IN_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Device: bits are set when the `IRQ_ON_NAK` or `IRQ_ON_STALL` bits are set. For EP0 this comes from `SIE_CTRL`. For all other endpoints it comes from the endpoint control register.  
+
+This register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).  
+
+For information about available fields see [ep_status_stall_nak](index.html) module"]
+pub struct EP_STATUS_STALL_NAK_SPEC;
+impl crate::RegisterSpec for EP_STATUS_STALL_NAK_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [ep_status_stall_nak::R](R) reader structure"]
+impl crate::Readable for EP_STATUS_STALL_NAK_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [ep_status_stall_nak::W](W) writer structure"]
+impl crate::Writable for EP_STATUS_STALL_NAK_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets EP_STATUS_STALL_NAK to value 0"]
+impl crate::Resettable for EP_STATUS_STALL_NAK_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
